MapSpec

Struct MapSpec 

pub struct MapSpec { /* private fields */ }
A map operation.

use ytsaurus_client::MapSpec;

let spec = MapSpec::new("./cat", ["//tmp/in"], ["//tmp/out"])
    .with_local_file("//tmp/cat")
    .with_memory_limit(512 * 1024 * 1024);

Implementations

Source

impl MapSpec

pub fn new<I, O>(command: impl Into<String>, inputs: I, outputs: O) -> Self

A map running command over inputs, writing outputs.

pub fn with_local_file(self, path: impl Into<String>) -> Self

Adds a Cypress file the job needs — normally the worker binary.

pub fn with_memory_limit(self, bytes: i64) -> Self

Sets the mapper’s memory limit, in bytes.

pub fn with_env(self, key: impl Into<String>, value: impl Into<String>) -> Self

Sets an environment variable for the job, e.g. RUST_BACKTRACE.

pub fn with_input_table_index(self) -> Self

Asks for the input table index to be delivered with each row.

Without this, Row::table_index is always 0.

pub fn with_job_count(self, count: i64) -> Self

Requests a specific job count.

pub fn with_raw(self, key: impl Into<String>, value: YsonValue) -> Self

Sets any spec field this builder does not model.

pub fn to_yson(&self) -> YsonValue

Renders the spec.